/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataLaunchdarklyEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether or not to require confirmation for flag and segment changes in this environment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#confirm_changes DataLaunchdarklyEnvironment#confirm_changes}
    */
    readonly confirmChanges?: boolean | cdktf.IResolvable;
    /**
    * Whether or not to default to sending data export events for flags created in the environment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#default_track_events DataLaunchdarklyEnvironment#default_track_events}
    */
    readonly defaultTrackEvents?: boolean | cdktf.IResolvable;
    /**
    * The TTL for the environment. This must be between 0 and 60 minutes. The TTL setting only applies to environments using the PHP SDK
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#default_ttl DataLaunchdarklyEnvironment#default_ttl}
    */
    readonly defaultTtl?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#id DataLaunchdarklyEnvironment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A project-unique key for the new environment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#key DataLaunchdarklyEnvironment#key}
    */
    readonly key: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#project_key DataLaunchdarklyEnvironment#project_key}
    */
    readonly projectKey: string;
    /**
    * Whether or not to require comments for flag and segment changes in this environment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#require_comments DataLaunchdarklyEnvironment#require_comments}
    */
    readonly requireComments?: boolean | cdktf.IResolvable;
    /**
    * Whether or not to use secure mode. Secure mode ensures a user of the client-side SDK cannot impersonate another user
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#secure_mode DataLaunchdarklyEnvironment#secure_mode}
    */
    readonly secureMode?: boolean | cdktf.IResolvable;
    /**
    * Tags associated with your resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#tags DataLaunchdarklyEnvironment#tags}
    */
    readonly tags?: string[];
    /**
    * approval_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#approval_settings DataLaunchdarklyEnvironment#approval_settings}
    */
    readonly approvalSettings?: DataLaunchdarklyEnvironmentApprovalSettings[] | cdktf.IResolvable;
}
export interface DataLaunchdarklyEnvironmentApprovalSettings {
    /**
    * Whether changes can be applied as long as minNumApprovals is met, regardless of whether any reviewers have declined a request. Defaults to true
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#can_apply_declined_changes DataLaunchdarklyEnvironment#can_apply_declined_changes}
    */
    readonly canApplyDeclinedChanges?: boolean | cdktf.IResolvable;
    /**
    * Whether requesters can approve or decline their own request. They may always comment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#can_review_own_request DataLaunchdarklyEnvironment#can_review_own_request}
    */
    readonly canReviewOwnRequest?: boolean | cdktf.IResolvable;
    /**
    * The number of approvals required before an approval request can be applied.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#min_num_approvals DataLaunchdarklyEnvironment#min_num_approvals}
    */
    readonly minNumApprovals?: number;
    /**
    * Whether any changes to flags in this environment will require approval. You may only set required or requiredApprovalTags, not both.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#required DataLaunchdarklyEnvironment#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
    /**
    * An array of tags used to specify which flags with those tags require approval. You may only set requiredApprovalTags or required, not both.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment#required_approval_tags DataLaunchdarklyEnvironment#required_approval_tags}
    */
    readonly requiredApprovalTags?: string[];
}
export declare function dataLaunchdarklyEnvironmentApprovalSettingsToTerraform(struct?: DataLaunchdarklyEnvironmentApprovalSettings | cdktf.IResolvable): any;
export declare class DataLaunchdarklyEnvironmentApprovalSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyEnvironmentApprovalSettings | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyEnvironmentApprovalSettings | cdktf.IResolvable | undefined);
    private _canApplyDeclinedChanges?;
    get canApplyDeclinedChanges(): boolean | cdktf.IResolvable;
    set canApplyDeclinedChanges(value: boolean | cdktf.IResolvable);
    resetCanApplyDeclinedChanges(): void;
    get canApplyDeclinedChangesInput(): boolean | cdktf.IResolvable | undefined;
    private _canReviewOwnRequest?;
    get canReviewOwnRequest(): boolean | cdktf.IResolvable;
    set canReviewOwnRequest(value: boolean | cdktf.IResolvable);
    resetCanReviewOwnRequest(): void;
    get canReviewOwnRequestInput(): boolean | cdktf.IResolvable | undefined;
    private _minNumApprovals?;
    get minNumApprovals(): number;
    set minNumApprovals(value: number);
    resetMinNumApprovals(): void;
    get minNumApprovalsInput(): number | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _requiredApprovalTags?;
    get requiredApprovalTags(): string[];
    set requiredApprovalTags(value: string[]);
    resetRequiredApprovalTags(): void;
    get requiredApprovalTagsInput(): string[] | undefined;
}
export declare class DataLaunchdarklyEnvironmentApprovalSettingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyEnvironmentApprovalSettings[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyEnvironmentApprovalSettingsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment launchdarkly_environment}
*/
export declare class DataLaunchdarklyEnvironment extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "launchdarkly_environment";
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/environment launchdarkly_environment} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataLaunchdarklyEnvironmentConfig
    */
    constructor(scope: Construct, id: string, config: DataLaunchdarklyEnvironmentConfig);
    get apiKey(): string;
    get clientSideId(): string;
    get color(): string;
    private _confirmChanges?;
    get confirmChanges(): boolean | cdktf.IResolvable;
    set confirmChanges(value: boolean | cdktf.IResolvable);
    resetConfirmChanges(): void;
    get confirmChangesInput(): boolean | cdktf.IResolvable | undefined;
    private _defaultTrackEvents?;
    get defaultTrackEvents(): boolean | cdktf.IResolvable;
    set defaultTrackEvents(value: boolean | cdktf.IResolvable);
    resetDefaultTrackEvents(): void;
    get defaultTrackEventsInput(): boolean | cdktf.IResolvable | undefined;
    private _defaultTtl?;
    get defaultTtl(): number;
    set defaultTtl(value: number);
    resetDefaultTtl(): void;
    get defaultTtlInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    get mobileKey(): string;
    get name(): string;
    private _projectKey?;
    get projectKey(): string;
    set projectKey(value: string);
    get projectKeyInput(): string | undefined;
    private _requireComments?;
    get requireComments(): boolean | cdktf.IResolvable;
    set requireComments(value: boolean | cdktf.IResolvable);
    resetRequireComments(): void;
    get requireCommentsInput(): boolean | cdktf.IResolvable | undefined;
    private _secureMode?;
    get secureMode(): boolean | cdktf.IResolvable;
    set secureMode(value: boolean | cdktf.IResolvable);
    resetSecureMode(): void;
    get secureModeInput(): boolean | cdktf.IResolvable | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _approvalSettings;
    get approvalSettings(): DataLaunchdarklyEnvironmentApprovalSettingsList;
    putApprovalSettings(value: DataLaunchdarklyEnvironmentApprovalSettings[] | cdktf.IResolvable): void;
    resetApprovalSettings(): void;
    get approvalSettingsInput(): cdktf.IResolvable | DataLaunchdarklyEnvironmentApprovalSettings[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
