/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataLaunchdarklyFeatureFlagEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * The LaunchDarkly environment key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#env_key DataLaunchdarklyFeatureFlagEnvironment#env_key}
    */
    readonly envKey: string;
    /**
    * The global feature flag's unique id in the format `<project_key>/<flag_key>`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#flag_id DataLaunchdarklyFeatureFlagEnvironment#flag_id}
    */
    readonly flagId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#id DataLaunchdarklyFeatureFlagEnvironment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The index of the variation to serve if targeting is disabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#off_variation DataLaunchdarklyFeatureFlagEnvironment#off_variation}
    */
    readonly offVariation?: number;
    /**
    * Whether targeting is enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#on DataLaunchdarklyFeatureFlagEnvironment#on}
    */
    readonly on?: boolean | cdktf.IResolvable;
    /**
    * Whether to send event data back to LaunchDarkly
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#track_events DataLaunchdarklyFeatureFlagEnvironment#track_events}
    */
    readonly trackEvents?: boolean | cdktf.IResolvable;
    /**
    * context_targets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#context_targets DataLaunchdarklyFeatureFlagEnvironment#context_targets}
    */
    readonly contextTargets?: DataLaunchdarklyFeatureFlagEnvironmentContextTargets[] | cdktf.IResolvable;
    /**
    * fallthrough block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#fallthrough DataLaunchdarklyFeatureFlagEnvironment#fallthrough}
    */
    readonly fallthrough?: DataLaunchdarklyFeatureFlagEnvironmentFallthrough;
    /**
    * prerequisites block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#prerequisites DataLaunchdarklyFeatureFlagEnvironment#prerequisites}
    */
    readonly prerequisites?: DataLaunchdarklyFeatureFlagEnvironmentPrerequisites[] | cdktf.IResolvable;
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#rules DataLaunchdarklyFeatureFlagEnvironment#rules}
    */
    readonly rules?: DataLaunchdarklyFeatureFlagEnvironmentRules[] | cdktf.IResolvable;
    /**
    * targets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#targets DataLaunchdarklyFeatureFlagEnvironment#targets}
    */
    readonly targets?: DataLaunchdarklyFeatureFlagEnvironmentTargets[] | cdktf.IResolvable;
}
export interface DataLaunchdarklyFeatureFlagEnvironmentContextTargets {
    /**
    * The context kind on which the flag should target in this environment. If the context_kind has not been previously specified at the project level, it will be automatically created on the project. User targets should be specified as targets attribute blocks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#context_kind DataLaunchdarklyFeatureFlagEnvironment#context_kind}
    */
    readonly contextKind: string;
    /**
    * List of user strings to target
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#values DataLaunchdarklyFeatureFlagEnvironment#values}
    */
    readonly values: string[];
    /**
    * Index of the variation to serve if a user_target is matched
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#variation DataLaunchdarklyFeatureFlagEnvironment#variation}
    */
    readonly variation: number;
}
export declare function dataLaunchdarklyFeatureFlagEnvironmentContextTargetsToTerraform(struct?: DataLaunchdarklyFeatureFlagEnvironmentContextTargets | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagEnvironmentContextTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagEnvironmentContextTargets | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagEnvironmentContextTargets | cdktf.IResolvable | undefined);
    private _contextKind?;
    get contextKind(): string;
    set contextKind(value: string);
    get contextKindInput(): string | undefined;
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
    private _variation?;
    get variation(): number;
    set variation(value: number);
    get variationInput(): number | undefined;
}
export declare class DataLaunchdarklyFeatureFlagEnvironmentContextTargetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagEnvironmentContextTargets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagEnvironmentContextTargetsOutputReference;
}
export interface DataLaunchdarklyFeatureFlagEnvironmentFallthrough {
    /**
    * Group percentage rollout by a custom attribute. This argument is only valid if rollout_weights is also specified
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#bucket_by DataLaunchdarklyFeatureFlagEnvironment#bucket_by}
    */
    readonly bucketBy?: string;
    /**
    * The context kind associated with the specified rollout. This argument is only valid if rollout_weights is also specified. If omitted, defaults to 'user'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#context_kind DataLaunchdarklyFeatureFlagEnvironment#context_kind}
    */
    readonly contextKind?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#rollout_weights DataLaunchdarklyFeatureFlagEnvironment#rollout_weights}
    */
    readonly rolloutWeights?: number[];
    /**
    * The integer variation index to serve in case of fallthrough
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#variation DataLaunchdarklyFeatureFlagEnvironment#variation}
    */
    readonly variation?: number;
}
export declare function dataLaunchdarklyFeatureFlagEnvironmentFallthroughToTerraform(struct?: DataLaunchdarklyFeatureFlagEnvironmentFallthroughOutputReference | DataLaunchdarklyFeatureFlagEnvironmentFallthrough): any;
export declare class DataLaunchdarklyFeatureFlagEnvironmentFallthroughOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataLaunchdarklyFeatureFlagEnvironmentFallthrough | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagEnvironmentFallthrough | undefined);
    private _bucketBy?;
    get bucketBy(): string;
    set bucketBy(value: string);
    resetBucketBy(): void;
    get bucketByInput(): string | undefined;
    private _contextKind?;
    get contextKind(): string;
    set contextKind(value: string);
    resetContextKind(): void;
    get contextKindInput(): string | undefined;
    private _rolloutWeights?;
    get rolloutWeights(): number[];
    set rolloutWeights(value: number[]);
    resetRolloutWeights(): void;
    get rolloutWeightsInput(): number[] | undefined;
    private _variation?;
    get variation(): number;
    set variation(value: number);
    resetVariation(): void;
    get variationInput(): number | undefined;
}
export interface DataLaunchdarklyFeatureFlagEnvironmentPrerequisites {
    /**
    * The prerequisite feature flag's key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#flag_key DataLaunchdarklyFeatureFlagEnvironment#flag_key}
    */
    readonly flagKey: string;
    /**
    * The index of the prerequisite feature flag's variation to target
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#variation DataLaunchdarklyFeatureFlagEnvironment#variation}
    */
    readonly variation: number;
}
export declare function dataLaunchdarklyFeatureFlagEnvironmentPrerequisitesToTerraform(struct?: DataLaunchdarklyFeatureFlagEnvironmentPrerequisites | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagEnvironmentPrerequisitesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagEnvironmentPrerequisites | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagEnvironmentPrerequisites | cdktf.IResolvable | undefined);
    private _flagKey?;
    get flagKey(): string;
    set flagKey(value: string);
    get flagKeyInput(): string | undefined;
    private _variation?;
    get variation(): number;
    set variation(value: number);
    get variationInput(): number | undefined;
}
export declare class DataLaunchdarklyFeatureFlagEnvironmentPrerequisitesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagEnvironmentPrerequisites[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagEnvironmentPrerequisitesOutputReference;
}
export interface DataLaunchdarklyFeatureFlagEnvironmentRulesClauses {
    /**
    * The user attribute to operate on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#attribute DataLaunchdarklyFeatureFlagEnvironment#attribute}
    */
    readonly attribute: string;
    /**
    * The context kind associated with this rule clause. If omitted, defaults to user
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#context_kind DataLaunchdarklyFeatureFlagEnvironment#context_kind}
    */
    readonly contextKind?: string;
    /**
    * Whether to negate the rule clause
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#negate DataLaunchdarklyFeatureFlagEnvironment#negate}
    */
    readonly negate?: boolean | cdktf.IResolvable;
    /**
    * The operator associated with the rule clause. Available options are in, endsWith, startsWith, matches, contains, lessThan, lessThanOrEqual, greaterThanOrEqual, before, after, segmentMatch, semVerEqual, semVerLessThan, and semVerGreaterThan
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#op DataLaunchdarklyFeatureFlagEnvironment#op}
    */
    readonly op: string;
    /**
    * The type for each of the clause's values. Available types are boolean, string, and number. If omitted, value_type defaults to string
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#value_type DataLaunchdarklyFeatureFlagEnvironment#value_type}
    */
    readonly valueType?: string;
    /**
    * The list of values associated with the rule clause
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#values DataLaunchdarklyFeatureFlagEnvironment#values}
    */
    readonly values: string[];
}
export declare function dataLaunchdarklyFeatureFlagEnvironmentRulesClausesToTerraform(struct?: DataLaunchdarklyFeatureFlagEnvironmentRulesClauses | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagEnvironmentRulesClausesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagEnvironmentRulesClauses | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagEnvironmentRulesClauses | cdktf.IResolvable | undefined);
    private _attribute?;
    get attribute(): string;
    set attribute(value: string);
    get attributeInput(): string | undefined;
    private _contextKind?;
    get contextKind(): string;
    set contextKind(value: string);
    resetContextKind(): void;
    get contextKindInput(): string | undefined;
    private _negate?;
    get negate(): boolean | cdktf.IResolvable;
    set negate(value: boolean | cdktf.IResolvable);
    resetNegate(): void;
    get negateInput(): boolean | cdktf.IResolvable | undefined;
    private _op?;
    get op(): string;
    set op(value: string);
    get opInput(): string | undefined;
    private _valueType?;
    get valueType(): string;
    set valueType(value: string);
    resetValueType(): void;
    get valueTypeInput(): string | undefined;
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
}
export declare class DataLaunchdarklyFeatureFlagEnvironmentRulesClausesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagEnvironmentRulesClauses[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagEnvironmentRulesClausesOutputReference;
}
export interface DataLaunchdarklyFeatureFlagEnvironmentRules {
    /**
    * Group percentage rollout by a custom attribute. This argument is only valid if rollout_weights is also specified
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#bucket_by DataLaunchdarklyFeatureFlagEnvironment#bucket_by}
    */
    readonly bucketBy?: string;
    /**
    * A human-readable description of the targeting rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#description DataLaunchdarklyFeatureFlagEnvironment#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#rollout_weights DataLaunchdarklyFeatureFlagEnvironment#rollout_weights}
    */
    readonly rolloutWeights?: number[];
    /**
    * The integer variation index to serve if the rule clauses evaluate to true. This argument is only valid if clauses are also specified
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#variation DataLaunchdarklyFeatureFlagEnvironment#variation}
    */
    readonly variation?: number;
    /**
    * clauses block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#clauses DataLaunchdarklyFeatureFlagEnvironment#clauses}
    */
    readonly clauses?: DataLaunchdarklyFeatureFlagEnvironmentRulesClauses[] | cdktf.IResolvable;
}
export declare function dataLaunchdarklyFeatureFlagEnvironmentRulesToTerraform(struct?: DataLaunchdarklyFeatureFlagEnvironmentRules | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagEnvironmentRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagEnvironmentRules | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagEnvironmentRules | cdktf.IResolvable | undefined);
    private _bucketBy?;
    get bucketBy(): string;
    set bucketBy(value: string);
    resetBucketBy(): void;
    get bucketByInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _rolloutWeights?;
    get rolloutWeights(): number[];
    set rolloutWeights(value: number[]);
    resetRolloutWeights(): void;
    get rolloutWeightsInput(): number[] | undefined;
    private _variation?;
    get variation(): number;
    set variation(value: number);
    resetVariation(): void;
    get variationInput(): number | undefined;
    private _clauses;
    get clauses(): DataLaunchdarklyFeatureFlagEnvironmentRulesClausesList;
    putClauses(value: DataLaunchdarklyFeatureFlagEnvironmentRulesClauses[] | cdktf.IResolvable): void;
    resetClauses(): void;
    get clausesInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagEnvironmentRulesClauses[] | undefined;
}
export declare class DataLaunchdarklyFeatureFlagEnvironmentRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagEnvironmentRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagEnvironmentRulesOutputReference;
}
export interface DataLaunchdarklyFeatureFlagEnvironmentTargets {
    /**
    * List of user strings to target
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#values DataLaunchdarklyFeatureFlagEnvironment#values}
    */
    readonly values: string[];
    /**
    * Index of the variation to serve if a user_target is matched
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment#variation DataLaunchdarklyFeatureFlagEnvironment#variation}
    */
    readonly variation: number;
}
export declare function dataLaunchdarklyFeatureFlagEnvironmentTargetsToTerraform(struct?: DataLaunchdarklyFeatureFlagEnvironmentTargets | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagEnvironmentTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagEnvironmentTargets | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagEnvironmentTargets | cdktf.IResolvable | undefined);
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
    private _variation?;
    get variation(): number;
    set variation(value: number);
    get variationInput(): number | undefined;
}
export declare class DataLaunchdarklyFeatureFlagEnvironmentTargetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagEnvironmentTargets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagEnvironmentTargetsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment launchdarkly_feature_flag_environment}
*/
export declare class DataLaunchdarklyFeatureFlagEnvironment extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "launchdarkly_feature_flag_environment";
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/feature_flag_environment launchdarkly_feature_flag_environment} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataLaunchdarklyFeatureFlagEnvironmentConfig
    */
    constructor(scope: Construct, id: string, config: DataLaunchdarklyFeatureFlagEnvironmentConfig);
    private _envKey?;
    get envKey(): string;
    set envKey(value: string);
    get envKeyInput(): string | undefined;
    private _flagId?;
    get flagId(): string;
    set flagId(value: string);
    get flagIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _offVariation?;
    get offVariation(): number;
    set offVariation(value: number);
    resetOffVariation(): void;
    get offVariationInput(): number | undefined;
    private _on?;
    get on(): boolean | cdktf.IResolvable;
    set on(value: boolean | cdktf.IResolvable);
    resetOn(): void;
    get onInput(): boolean | cdktf.IResolvable | undefined;
    private _trackEvents?;
    get trackEvents(): boolean | cdktf.IResolvable;
    set trackEvents(value: boolean | cdktf.IResolvable);
    resetTrackEvents(): void;
    get trackEventsInput(): boolean | cdktf.IResolvable | undefined;
    private _contextTargets;
    get contextTargets(): DataLaunchdarklyFeatureFlagEnvironmentContextTargetsList;
    putContextTargets(value: DataLaunchdarklyFeatureFlagEnvironmentContextTargets[] | cdktf.IResolvable): void;
    resetContextTargets(): void;
    get contextTargetsInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagEnvironmentContextTargets[] | undefined;
    private _fallthrough;
    get fallthrough(): DataLaunchdarklyFeatureFlagEnvironmentFallthroughOutputReference;
    putFallthrough(value: DataLaunchdarklyFeatureFlagEnvironmentFallthrough): void;
    resetFallthrough(): void;
    get fallthroughInput(): DataLaunchdarklyFeatureFlagEnvironmentFallthrough | undefined;
    private _prerequisites;
    get prerequisites(): DataLaunchdarklyFeatureFlagEnvironmentPrerequisitesList;
    putPrerequisites(value: DataLaunchdarklyFeatureFlagEnvironmentPrerequisites[] | cdktf.IResolvable): void;
    resetPrerequisites(): void;
    get prerequisitesInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagEnvironmentPrerequisites[] | undefined;
    private _rules;
    get rules(): DataLaunchdarklyFeatureFlagEnvironmentRulesList;
    putRules(value: DataLaunchdarklyFeatureFlagEnvironmentRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagEnvironmentRules[] | undefined;
    private _targets;
    get targets(): DataLaunchdarklyFeatureFlagEnvironmentTargetsList;
    putTargets(value: DataLaunchdarklyFeatureFlagEnvironmentTargets[] | cdktf.IResolvable): void;
    resetTargets(): void;
    get targetsInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagEnvironmentTargets[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
