/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataLaunchdarklyWebhookConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the webhook
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#id DataLaunchdarklyWebhook#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A human-readable name for your webhook
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#name DataLaunchdarklyWebhook#name}
    */
    readonly name?: string;
    /**
    * If sign is true, and the secret attribute is omitted, LaunchDarkly will automatically generate a secret for you
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#secret DataLaunchdarklyWebhook#secret}
    */
    readonly secret?: string;
    /**
    * Tags associated with your resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#tags DataLaunchdarklyWebhook#tags}
    */
    readonly tags?: string[];
    /**
    * statements block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#statements DataLaunchdarklyWebhook#statements}
    */
    readonly statements?: DataLaunchdarklyWebhookStatements[] | cdktf.IResolvable;
}
export interface DataLaunchdarklyWebhookStatements {
    /**
    * An action to perform on a resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#actions DataLaunchdarklyWebhook#actions}
    */
    readonly actions?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#effect DataLaunchdarklyWebhook#effect}
    */
    readonly effect: string;
    /**
    * Targeted actions will be those actions NOT in this list. The 'actions' field must be empty to use this field
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#not_actions DataLaunchdarklyWebhook#not_actions}
    */
    readonly notActions?: string[];
    /**
    * Targeted resources will be those resources NOT in this list. The 'resources' field must be empty to use this field
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#not_resources DataLaunchdarklyWebhook#not_resources}
    */
    readonly notResources?: string[];
    /**
    * A list of LaunchDarkly resource specifiers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook#resources DataLaunchdarklyWebhook#resources}
    */
    readonly resources?: string[];
}
export declare function dataLaunchdarklyWebhookStatementsToTerraform(struct?: DataLaunchdarklyWebhookStatements | cdktf.IResolvable): any;
export declare class DataLaunchdarklyWebhookStatementsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyWebhookStatements | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyWebhookStatements | cdktf.IResolvable | undefined);
    private _actions?;
    get actions(): string[];
    set actions(value: string[]);
    resetActions(): void;
    get actionsInput(): string[] | undefined;
    private _effect?;
    get effect(): string;
    set effect(value: string);
    get effectInput(): string | undefined;
    private _notActions?;
    get notActions(): string[];
    set notActions(value: string[]);
    resetNotActions(): void;
    get notActionsInput(): string[] | undefined;
    private _notResources?;
    get notResources(): string[];
    set notResources(value: string[]);
    resetNotResources(): void;
    get notResourcesInput(): string[] | undefined;
    private _resources?;
    get resources(): string[];
    set resources(value: string[]);
    resetResources(): void;
    get resourcesInput(): string[] | undefined;
}
export declare class DataLaunchdarklyWebhookStatementsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyWebhookStatements[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyWebhookStatementsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook launchdarkly_webhook}
*/
export declare class DataLaunchdarklyWebhook extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "launchdarkly_webhook";
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.13.2/docs/data-sources/webhook launchdarkly_webhook} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataLaunchdarklyWebhookConfig
    */
    constructor(scope: Construct, id: string, config: DataLaunchdarklyWebhookConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get on(): cdktf.IResolvable;
    private _secret?;
    get secret(): string;
    set secret(value: string);
    resetSecret(): void;
    get secretInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    get url(): string;
    private _statements;
    get statements(): DataLaunchdarklyWebhookStatementsList;
    putStatements(value: DataLaunchdarklyWebhookStatements[] | cdktf.IResolvable): void;
    resetStatements(): void;
    get statementsInput(): cdktf.IResolvable | DataLaunchdarklyWebhookStatements[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
